'use strict';
var Q = require('q');
var readFile = Q.denodeify(require('fs').readFile);
var resolve = require('path').resolve;
var semver = require('semver');

function presetOpts(cb) {
  var parserOpts = {
    headerPattern: /^\[\[(.*)]] (.*)$/,
    headerCorrespondence: [
      'type',
      'shortDesc'
    ]
  };

  var writerOpts = {
    transform: function(commit) {
      if (commit.type === 'FEAT') {
        commit.type = 'Features';
      } else if (commit.type === 'FIX') {
        commit.type = 'Bug Fixes';
      } else {
        return;
      }

      if (!commit.type || typeof commit.type !== 'string') {
        return;
      }

      if (typeof commit.hash === 'string') {
        commit.hash = commit.hash.substring(0, 7);
      }

      return commit;
    },
    groupBy: 'type',
    commitGroupsSort: 'title',
    commitsSort: ['type', 'shortDesc'],
    generateOn: function(commit) {
      return semver.valid(commit.version);
    }
  };

  Q.all([
    readFile(resolve(__dirname, '../templates/jshint/template.hbs'), 'utf-8'),
    readFile(resolve(__dirname, '../templates/jshint/header.hbs'), 'utf-8'),
    readFile(resolve(__dirname, '../templates/jshint/commit.hbs'), 'utf-8')
  ])
    .spread(function(template, header, commit) {
      writerOpts.mainTemplate = template;
      writerOpts.headerPartial = header;
      writerOpts.commitPartial = commit;

      cb(null, {
        parserOpts: parserOpts,
        writerOpts: writerOpts
      });
    });
}

module.exports = presetOpts;
